@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------
 # tests/examples/test_mocking_side_effects.py
 #
-# Copyright (C) 2018 - 2020 Maciej Wiatrzyk
+# Copyright (C) 2019 - 2020 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
 #
 # This file is part of Mockify library and is released under the terms of the
 # MIT license: http://opensource.org/licenses/mit-license.php.
@@ -10,10 +10,10 @@
 # ---------------------------------------------------------------------------
 from io import BytesIO
 
-from mockify import satisfied
-from mockify.mock import Mock
 from mockify.actions import Invoke
+from mockify.core import satisfied
 from mockify.matchers import _
+from mockify.mock import Mock
 
 
 class ImageAdapter:
